@@ -25,13 +25,12 @@
    meant to be used within the GNOME VFS and its modules: they are not for
    public consumption through the external API.  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-#include <string.h>
+#include "gnome-vfs-cancellable-ops.h"
 
-#include "gnome-vfs.h"
-#include "gnome-vfs-private.h"
+#include <glib/gmessages.h>
+#include <glib/gutils.h>
+#include <string.h>
 
 GnomeVFSResult
 gnome_vfs_open_uri_cancellable (GnomeVFSHandle **handle,
